@@ -49,16 +49,6 @@ Q_DECLARE_FLAGS(MemberChanges, MemberChange)
 Q_DECLARE_OPERATORS_FOR_FLAGS(MemberChanges)
 };
 
-QString EventHandler::id(const Quotient::RoomEvent *event)
-{
-    if (event == nullptr) {
-        qCWarning(EventHandling) << "id called with event set to nullptr.";
-        return {};
-    }
-
-    return !event->id().isEmpty() ? event->id() : event->transactionId();
-}
-
 QString EventHandler::authorDisplayName(const NeoChatRoom *room, const Quotient::RoomEvent *event, bool isPending)
 {
     if (room == nullptr) {
@@ -70,9 +60,9 @@ QString EventHandler::authorDisplayName(const NeoChatRoom *room, const Quotient:
         return {};
     }
 
-    if (is<RoomMemberEvent>(*event) && !event->unsignedJson()[QStringLiteral("prev_content")][QStringLiteral("displayname")].isNull()
+    if (is<RoomMemberEvent>(*event) && event->unsignedJson()["prev_content"_L1].toObject().contains("displayname"_L1)
         && event->stateKey() == event->senderId()) {
-        auto previousDisplayName = event->unsignedJson()[QStringLiteral("prev_content")][QStringLiteral("displayname")].toString().toHtmlEscaped();
+        auto previousDisplayName = event->unsignedJson()["prev_content"_L1]["displayname"_L1].toString().toHtmlEscaped();
         if (previousDisplayName.isEmpty()) {
             previousDisplayName = event->senderId();
         }
@@ -96,32 +86,39 @@ QString EventHandler::singleLineAuthorDisplayname(const NeoChatRoom *room, const
 
     const auto author = isPending ? room->localMember() : room->member(event->senderId());
     auto displayName = author.displayName();
-    displayName.replace(QStringLiteral("<br>\n"), QStringLiteral(" "));
-    displayName.replace(QStringLiteral("<br>"), QStringLiteral(" "));
-    displayName.replace(QStringLiteral("<br />\n"), QStringLiteral(" "));
-    displayName.replace(QStringLiteral("<br />"), QStringLiteral(" "));
-    displayName.replace(u'\n', QStringLiteral(" "));
-    displayName.replace(u'\u2028', QStringLiteral(" "));
+    displayName.replace(u"<br>\n"_s, u" "_s);
+    displayName.replace(u"<br>"_s, u" "_s);
+    displayName.replace(u"<br />\n"_s, u" "_s);
+    displayName.replace(u"<br />"_s, u" "_s);
+    displayName.replace(u'\n', u" "_s);
+    displayName.replace(u'\u2028', u" "_s);
     return displayName;
 }
 
-QDateTime EventHandler::time(const Quotient::RoomEvent *event, bool isPending, QDateTime lastUpdated)
+QDateTime EventHandler::time(const NeoChatRoom *room, const Quotient::RoomEvent *event, bool isPending)
 {
+    if (room == nullptr) {
+        qCWarning(EventHandling) << "time called with room set to nullptr.";
+        return {};
+    }
     if (event == nullptr) {
         qCWarning(EventHandling) << "time called with event set to nullptr.";
         return {};
     }
-    if (isPending && lastUpdated == QDateTime()) {
-        qCWarning(EventHandling) << "a value must be provided for lastUpdated for a pending event.";
+
+    if (isPending) {
+        const auto pendingIt = room->findPendingEvent(event->transactionId());
+        if (pendingIt != room->pendingEvents().end()) {
+            return pendingIt->lastUpdated();
+        }
         return {};
     }
-
-    return isPending ? lastUpdated : event->originTimestamp();
+    return event->originTimestamp();
 }
 
-QString EventHandler::timeString(const Quotient::RoomEvent *event, bool relative, QLocale::FormatType format, bool isPending, QDateTime lastUpdated)
+QString EventHandler::timeString(const NeoChatRoom *room, const Quotient::RoomEvent *event, bool relative, QLocale::FormatType format, bool isPending)
 {
-    auto ts = time(event, isPending, lastUpdated);
+    auto ts = time(room, event, isPending);
     if (ts.isValid()) {
         if (relative) {
             KFormat formatter;
@@ -133,9 +130,9 @@ QString EventHandler::timeString(const Quotient::RoomEvent *event, bool relative
     return {};
 }
 
-QString EventHandler::timeString(const Quotient::RoomEvent *event, const QString &format, bool isPending, const QDateTime &lastUpdated)
+QString EventHandler::timeString(const NeoChatRoom *room, const Quotient::RoomEvent *event, const QString &format, bool isPending)
 {
-    return time(event, isPending, lastUpdated).toLocalTime().toString(format);
+    return time(room, event, isPending).toLocalTime().toString(format);
 }
 
 bool EventHandler::isHighlighted(const NeoChatRoom *room, const Quotient::RoomEvent *event)
@@ -205,7 +202,7 @@ bool EventHandler::isHidden(const NeoChatRoom *room, const Quotient::RoomEvent *
     }
 
     // hide ending live location beacons
-    if (event->isStateEvent() && event->matrixType() == "org.matrix.msc3672.beacon_info"_ls && !event->contentJson()["live"_ls].toBool()) {
+    if (event->isStateEvent() && event->matrixType() == "org.matrix.msc3672.beacon_info"_L1 && !event->contentJson()["live"_L1].toBool()) {
         return true;
     }
 
@@ -214,7 +211,7 @@ bool EventHandler::isHidden(const NeoChatRoom *room, const Quotient::RoomEvent *
 
 Qt::TextFormat EventHandler::messageBodyInputFormat(const Quotient::RoomMessageEvent &event)
 {
-    if (event.mimeType().name() == "text/plain"_ls) {
+    if (event.mimeType().name() == "text/plain"_L1) {
         return Qt::PlainText;
     } else {
         return Qt::RichText;
@@ -291,7 +288,7 @@ QString EventHandler::markdownBody(const Quotient::RoomEvent *event)
 
 QString EventHandler::getBody(const NeoChatRoom *room, const Quotient::RoomEvent *event, Qt::TextFormat format, bool stripNewlines)
 {
-    if (event->isRedacted()) {
+    if (event->isRedacted() && !event->isStateEvent()) {
         auto reason = event->redactedBecause()->reason();
         return (reason.isEmpty()) ? i18n("<i>[This message was deleted]</i>") : i18n("<i>[This message was deleted: %1]</i>", reason.toHtmlEscaped());
     }
@@ -319,8 +316,8 @@ QString EventHandler::getBody(const NeoChatRoom *room, const Quotient::RoomEvent
             }
 
             if (prettyPrint) {
-                subjectName = QStringLiteral("<a href=\"https://matrix.to/#/%1\" style=\"color: %2\">%3</a>")
-                                  .arg(e.userId(), room->member(e.userId()).color().name(), subjectName);
+                subjectName =
+                    u"<a href=\"https://matrix.to/#/%1\" style=\"color: %2\">%3</a>"_s.arg(e.userId(), room->member(e.userId()).color().name(), subjectName);
             }
 
             // The below code assumes senderName output in AuthorRole
@@ -386,7 +383,7 @@ QString EventHandler::getBody(const NeoChatRoom *room, const Quotient::RoomEvent
                 if (e.senderId() == e.userId()) {
                     return i18n("left the room");
                 }
-                if (const auto &reason = e.contentJson()["reason"_ls].toString().toHtmlEscaped(); !reason.isEmpty()) {
+                if (const auto &reason = e.contentJson()["reason"_L1].toString().toHtmlEscaped(); !reason.isEmpty()) {
                     return i18n("has put %1 out of the room: %2", subjectName, reason);
                 }
                 return i18n("has put %1 out of the room", subjectName);
@@ -401,7 +398,7 @@ QString EventHandler::getBody(const NeoChatRoom *room, const Quotient::RoomEvent
                     return i18n("self-banned from the room");
                 }
             case Membership::Knock: {
-                QString reason(e.contentJson()["reason"_ls].toString().toHtmlEscaped());
+                QString reason(e.contentJson()["reason"_L1].toString().toHtmlEscaped());
                 return reason.isEmpty() ? i18n("requested an invite") : i18n("requested an invite with reason: %1", reason);
             }
             default:;
@@ -429,26 +426,26 @@ QString EventHandler::getBody(const NeoChatRoom *room, const Quotient::RoomEvent
         },
         [prettyPrint](const RoomCreateEvent &e) {
             return e.isUpgrade()
-                ? i18n("upgraded the room to version %1", e.version().isEmpty() ? "1"_ls : (prettyPrint ? e.version().toHtmlEscaped() : e.version()))
-                : i18n("created the room, version %1", e.version().isEmpty() ? "1"_ls : (prettyPrint ? e.version().toHtmlEscaped() : e.version()));
+                ? i18n("upgraded the room to version %1", e.version().isEmpty() ? "1"_L1 : (prettyPrint ? e.version().toHtmlEscaped() : e.version()))
+                : i18n("created the room, version %1", e.version().isEmpty() ? "1"_L1 : (prettyPrint ? e.version().toHtmlEscaped() : e.version()));
         },
         [](const RoomPowerLevelsEvent &) {
             return i18nc("'power level' means permission level", "changed the power levels for this room");
         },
         [](const LocationBeaconEvent &e) {
-            return e.contentJson()["description"_ls].toString();
+            return e.contentJson()["description"_L1].toString();
         },
         [](const RoomServerAclEvent &) {
             return i18n("changed the server access control lists for this room");
         },
         [](const WidgetEvent &e) {
-            if (e.fullJson()["unsigned"_ls]["prev_content"_ls].toObject().isEmpty()) {
-                return i18nc("[User] added <name> widget", "added %1 widget", e.contentJson()["name"_ls].toString());
+            if (e.fullJson()["unsigned"_L1]["prev_content"_L1].toObject().isEmpty()) {
+                return i18nc("[User] added <name> widget", "added %1 widget", e.contentJson()["name"_L1].toString());
             }
             if (e.contentJson().isEmpty()) {
-                return i18nc("[User] removed <name> widget", "removed %1 widget", e.fullJson()["unsigned"_ls]["prev_content"_ls]["name"_ls].toString());
+                return i18nc("[User] removed <name> widget", "removed %1 widget", e.fullJson()["unsigned"_L1]["prev_content"_L1]["name"_L1].toString());
             }
-            return i18nc("[User] configured <name> widget", "configured %1 widget", e.contentJson()["name"_ls].toString());
+            return i18nc("[User] configured <name> widget", "configured %1 widget", e.contentJson()["name"_L1].toString());
         },
         [prettyPrint](const StateEvent &e) {
             return e.stateKey().isEmpty() ? i18n("updated %1 state", e.matrixType())
@@ -469,7 +466,7 @@ QString EventHandler::getMessageBody(const NeoChatRoom *room, const RoomMessageE
         if (fileCaption.isEmpty()) {
             fileCaption = event.plainBody();
         } else if (fileCaption != event.plainBody()) {
-            fileCaption = event.plainBody() + " | "_ls + fileCaption;
+            fileCaption = event.plainBody() + " | "_L1 + fileCaption;
         }
         textHandler.setData(fileCaption);
         return !fileCaption.isEmpty() ? textHandler.handleRecievePlainText(Qt::PlainText, stripNewlines) : i18n("a file");
@@ -485,7 +482,7 @@ QString EventHandler::getMessageBody(const NeoChatRoom *room, const RoomMessageE
     textHandler.setData(body);
 
     Qt::TextFormat inputFormat;
-    if (event.mimeType().name() == "text/plain"_ls) {
+    if (event.mimeType().name() == "text/plain"_L1) {
         inputFormat = Qt::PlainText;
     } else {
         inputFormat = Qt::RichText;
@@ -508,12 +505,12 @@ QString EventHandler::genericBody(const NeoChatRoom *room, const Quotient::RoomE
         qCWarning(EventHandling) << "genericBody called with event set to nullptr.";
         return {};
     }
-    if (event->isRedacted()) {
+    if (event->isRedacted() && !event->isStateEvent()) {
         return i18n("<i>[This message was deleted]</i>");
     }
 
     const auto sender = room->member(event->senderId());
-    const auto senderString = QStringLiteral("<a href=\"https://matrix.to/#/%1\">%2</a>").arg(sender.id(), sender.htmlSafeDisplayName());
+    const auto senderString = u"<a href=\"https://matrix.to/#/%1\">%2</a>"_s.arg(sender.id(), sender.htmlSafeDisplayName());
 
     return switchOnType(
         *event,
@@ -642,7 +639,7 @@ QString EventHandler::genericBody(const NeoChatRoom *room, const Quotient::RoomE
             return i18n("%1 changed the server access control lists for this room", senderString);
         },
         [senderString](const WidgetEvent &e) {
-            if (e.fullJson()["unsigned"_ls]["prev_content"_ls].toObject().isEmpty()) {
+            if (e.fullJson()["unsigned"_L1]["prev_content"_L1].toObject().isEmpty()) {
                 return i18n("%1 added a widget", senderString);
             }
             if (e.contentJson().isEmpty()) {
@@ -669,7 +666,7 @@ QString EventHandler::subtitleText(const NeoChatRoom *room, const Quotient::Room
         qCWarning(EventHandling) << "subtitleText called with event set to nullptr.";
         return {};
     }
-    return singleLineAuthorDisplayname(room, event) + (event->isStateEvent() ? QLatin1String(" ") : QLatin1String(": ")) + plainBody(room, event, true);
+    return singleLineAuthorDisplayname(room, event) + (event->isStateEvent() ? u" "_s : u": "_s) + plainBody(room, event, true);
 }
 
 QVariantMap EventHandler::mediaInfo(const NeoChatRoom *room, const Quotient::RoomEvent *event)
@@ -700,7 +697,7 @@ QVariantMap EventHandler::getMediaInfoForEvent(const NeoChatRoom *room, const Qu
         QVariantMap mediaInfo = getMediaInfoFromFileInfo(room, content.get(), eventId, false, false);
         // if filename isn't specifically given, it is in body
         // https://spec.matrix.org/latest/client-server-api/#mfile
-        mediaInfo["filename"_ls] = content->commonInfo().originalName.isEmpty() ? roomMessageEvent->plainBody() : content->commonInfo().originalName;
+        mediaInfo["filename"_L1] = content->commonInfo().originalName.isEmpty() ? roomMessageEvent->plainBody() : content->commonInfo().originalName;
 
         return mediaInfo;
     } else if (event->is<StickerEvent>()) {
@@ -722,80 +719,80 @@ QVariantMap EventHandler::getMediaInfoFromFileInfo(const NeoChatRoom *room,
     QVariantMap mediaInfo;
 
     // Get the mxc URL for the media.
-    if (!fileContent->url().isValid() || fileContent->url().scheme() != QStringLiteral("mxc") || eventId.isEmpty()) {
-        mediaInfo["source"_ls] = QUrl();
+    if (!fileContent->url().isValid() || fileContent->url().scheme() != u"mxc"_s || eventId.isEmpty()) {
+        mediaInfo["source"_L1] = QUrl();
     } else {
         QUrl source = room->makeMediaUrl(eventId, fileContent->url());
 
         if (source.isValid()) {
-            mediaInfo["source"_ls] = source;
+            mediaInfo["source"_L1] = source;
         } else {
-            mediaInfo["source"_ls] = QUrl();
+            mediaInfo["source"_L1] = QUrl();
         }
     }
 
     auto mimeType = fileContent->type();
     // Add the MIME type for the media if available.
-    mediaInfo["mimeType"_ls] = mimeType.name();
+    mediaInfo["mimeType"_L1] = mimeType.name();
 
     // Add the MIME type icon if available.
-    mediaInfo["mimeIcon"_ls] = mimeType.iconName();
+    mediaInfo["mimeIcon"_L1] = mimeType.iconName();
 
     // Add media size if available.
-    mediaInfo["size"_ls] = fileContent->commonInfo().payloadSize;
+    mediaInfo["size"_L1] = fileContent->commonInfo().payloadSize;
 
-    mediaInfo["isSticker"_ls] = isSticker;
+    mediaInfo["isSticker"_L1] = isSticker;
 
     // Add parameter depending on media type.
-    if (mimeType.name().contains(QStringLiteral("image"))) {
+    if (mimeType.name().contains(u"image"_s)) {
         if (auto castInfo = static_cast<const EventContent::ImageContent *>(fileContent)) {
-            mediaInfo["width"_ls] = castInfo->imageSize.width();
-            mediaInfo["height"_ls] = castInfo->imageSize.height();
+            mediaInfo["width"_L1] = castInfo->imageSize.width();
+            mediaInfo["height"_L1] = castInfo->imageSize.height();
 
             // TODO: Images in certain formats (e.g. WebP) will be erroneously marked as animated, even if they are static.
-            mediaInfo["animated"_ls] = QMovie::supportedFormats().contains(mimeType.preferredSuffix().toUtf8());
+            mediaInfo["animated"_L1] = QMovie::supportedFormats().contains(mimeType.preferredSuffix().toUtf8());
 
             QVariantMap tempInfo;
             auto thumbnailInfo = getMediaInfoFromTumbnail(room, castInfo->thumbnail, eventId);
-            if (thumbnailInfo["source"_ls].toUrl().scheme() == "mxc"_ls) {
+            if (thumbnailInfo["source"_L1].toUrl().scheme() == "mxc"_L1) {
                 tempInfo = thumbnailInfo;
             } else {
-                QString blurhash = castInfo->originalInfoJson["xyz.amorgan.blurhash"_ls].toString();
+                QString blurhash = castInfo->originalInfoJson["xyz.amorgan.blurhash"_L1].toString();
                 if (blurhash.isEmpty()) {
-                    tempInfo["source"_ls] = QUrl();
+                    tempInfo["source"_L1] = QUrl();
                 } else {
-                    tempInfo["source"_ls] = QUrl("image://blurhash/"_ls + blurhash);
+                    tempInfo["source"_L1] = QUrl("image://blurhash/"_L1 + blurhash);
                 }
             }
-            mediaInfo["tempInfo"_ls] = tempInfo;
+            mediaInfo["tempInfo"_L1] = tempInfo;
         }
     }
-    if (mimeType.name().contains(QStringLiteral("video"))) {
+    if (mimeType.name().contains(u"video"_s)) {
         if (auto castInfo = static_cast<const EventContent::VideoContent *>(fileContent)) {
-            mediaInfo["width"_ls] = castInfo->imageSize.width();
-            mediaInfo["height"_ls] = castInfo->imageSize.height();
-            mediaInfo["duration"_ls] = castInfo->duration;
+            mediaInfo["width"_L1] = castInfo->imageSize.width();
+            mediaInfo["height"_L1] = castInfo->imageSize.height();
+            mediaInfo["duration"_L1] = castInfo->duration;
 
             if (!isThumbnail) {
                 QVariantMap tempInfo;
                 auto thumbnailInfo = getMediaInfoFromTumbnail(room, castInfo->thumbnail, eventId);
-                if (thumbnailInfo["source"_ls].toUrl().scheme() == "mxc"_ls) {
+                if (thumbnailInfo["source"_L1].toUrl().scheme() == "mxc"_L1) {
                     tempInfo = thumbnailInfo;
                 } else {
-                    QString blurhash = castInfo->originalInfoJson["xyz.amorgan.blurhash"_ls].toString();
+                    QString blurhash = castInfo->originalInfoJson["xyz.amorgan.blurhash"_L1].toString();
                     if (blurhash.isEmpty()) {
-                        tempInfo["source"_ls] = QUrl();
+                        tempInfo["source"_L1] = QUrl();
                     } else {
-                        tempInfo["source"_ls] = QUrl("image://blurhash/"_ls + blurhash);
+                        tempInfo["source"_L1] = QUrl("image://blurhash/"_L1 + blurhash);
                     }
                 }
-                mediaInfo["tempInfo"_ls] = tempInfo;
+                mediaInfo["tempInfo"_L1] = tempInfo;
             }
         }
     }
-    if (mimeType.name().contains(QStringLiteral("audio"))) {
+    if (mimeType.name().contains(u"audio"_s)) {
         if (auto castInfo = static_cast<const EventContent::AudioContent *>(fileContent)) {
-            mediaInfo["duration"_ls] = castInfo->duration;
+            mediaInfo["duration"_L1] = castInfo->duration;
         }
     }
 
@@ -806,59 +803,34 @@ QVariantMap EventHandler::getMediaInfoFromTumbnail(const NeoChatRoom *room, cons
 {
     QVariantMap thumbnailInfo;
 
-    if (!thumbnail.url().isValid() || thumbnail.url().scheme() != QStringLiteral("mxc") || eventId.isEmpty()) {
-        thumbnailInfo["source"_ls] = QUrl();
+    if (!thumbnail.url().isValid() || thumbnail.url().scheme() != u"mxc"_s || eventId.isEmpty()) {
+        thumbnailInfo["source"_L1] = QUrl();
     } else {
         QUrl source = room->makeMediaUrl(eventId, thumbnail.url());
 
         if (source.isValid()) {
-            thumbnailInfo["source"_ls] = source;
+            thumbnailInfo["source"_L1] = source;
         } else {
-            thumbnailInfo["source"_ls] = QUrl();
+            thumbnailInfo["source"_L1] = QUrl();
         }
     }
 
     auto mimeType = thumbnail.mimeType;
     // Add the MIME type for the media if available.
-    thumbnailInfo["mimeType"_ls] = mimeType.name();
+    thumbnailInfo["mimeType"_L1] = mimeType.name();
 
     // Add the MIME type icon if available.
-    thumbnailInfo["mimeIcon"_ls] = mimeType.iconName();
+    thumbnailInfo["mimeIcon"_L1] = mimeType.iconName();
 
     // Add media size if available.
-    thumbnailInfo["size"_ls] = thumbnail.payloadSize;
+    thumbnailInfo["size"_L1] = thumbnail.payloadSize;
 
-    thumbnailInfo["width"_ls] = thumbnail.imageSize.width();
-    thumbnailInfo["height"_ls] = thumbnail.imageSize.height();
+    thumbnailInfo["width"_L1] = thumbnail.imageSize.width();
+    thumbnailInfo["height"_L1] = thumbnail.imageSize.height();
 
     return thumbnailInfo;
 }
 
-bool EventHandler::hasReply(const Quotient::RoomEvent *event, bool showFallbacks)
-{
-    if (event == nullptr) {
-        qCWarning(EventHandling) << "hasReply called with event set to nullptr.";
-        return false;
-    }
-
-    const auto relations = event->contentPart<QJsonObject>("m.relates_to"_ls);
-    if (!relations.isEmpty()) {
-        const bool hasReplyRelation = relations.contains("m.in_reply_to"_ls);
-        bool isFallingBack = relations["is_falling_back"_ls].toBool();
-        return hasReplyRelation && (showFallbacks ? true : !isFallingBack);
-    }
-    return false;
-}
-
-QString EventHandler::replyId(const Quotient::RoomEvent *event)
-{
-    if (event == nullptr) {
-        qCWarning(EventHandling) << "replyId called with event set to nullptr.";
-        return {};
-    }
-    return event->contentJson()["m.relates_to"_ls].toObject()["m.in_reply_to"_ls].toObject()["event_id"_ls].toString();
-}
-
 Quotient::RoomMember EventHandler::replyAuthor(const NeoChatRoom *room, const Quotient::RoomEvent *event)
 {
     if (room == nullptr) {
@@ -877,38 +849,6 @@ Quotient::RoomMember EventHandler::replyAuthor(const NeoChatRoom *room, const Qu
     }
 }
 
-bool EventHandler::isThreaded(const Quotient::RoomEvent *event)
-{
-    if (event == nullptr) {
-        qCWarning(EventHandling) << "isThreaded called with event set to nullptr.";
-        return false;
-    }
-
-    return (event->contentPart<QJsonObject>("m.relates_to"_ls).contains("rel_type"_ls)
-            && event->contentPart<QJsonObject>("m.relates_to"_ls)["rel_type"_ls].toString() == "m.thread"_ls)
-        || (!event->unsignedPart<QJsonObject>("m.relations"_ls).isEmpty() && event->unsignedPart<QJsonObject>("m.relations"_ls).contains("m.thread"_ls));
-}
-
-QString EventHandler::threadRoot(const Quotient::RoomEvent *event)
-{
-    if (event == nullptr) {
-        qCWarning(EventHandling) << "threadRoot called with event set to nullptr.";
-        return {};
-    }
-
-    // Get the thread root ID from m.relates_to if it exists.
-    if (event->contentPart<QJsonObject>("m.relates_to"_ls).contains("rel_type"_ls)
-        && event->contentPart<QJsonObject>("m.relates_to"_ls)["rel_type"_ls].toString() == "m.thread"_ls) {
-        return event->contentPart<QJsonObject>("m.relates_to"_ls)["event_id"_ls].toString();
-    }
-    // For thread root events they have an m.relations in the unsigned part with a m.thread object.
-    // If so return the event ID as it is the root.
-    if (!event->unsignedPart<QJsonObject>("m.relations"_ls).isEmpty() && event->unsignedPart<QJsonObject>("m.relations"_ls).contains("m.thread"_ls)) {
-        return id(event);
-    }
-    return {};
-}
-
 float EventHandler::latitude(const Quotient::RoomEvent *event)
 {
     if (event == nullptr) {
@@ -916,7 +856,7 @@ float EventHandler::latitude(const Quotient::RoomEvent *event)
         return -100.0;
     }
 
-    const auto geoUri = event->contentJson()["geo_uri"_ls].toString();
+    const auto geoUri = event->contentJson()["geo_uri"_L1].toString();
     if (geoUri.isEmpty()) {
         return -100.0; // latitude runs from -90deg to +90deg so -100 is out of range.
     }
@@ -931,7 +871,7 @@ float EventHandler::longitude(const Quotient::RoomEvent *event)
         return -200.0;
     }
 
-    const auto geoUri = event->contentJson()["geo_uri"_ls].toString();
+    const auto geoUri = event->contentJson()["geo_uri"_L1].toString();
     if (geoUri.isEmpty()) {
         return -200.0; // longitude runs from -180deg to +180deg so -200 is out of range.
     }
@@ -946,7 +886,7 @@ QString EventHandler::locationAssetType(const Quotient::RoomEvent *event)
         return {};
     }
 
-    const auto assetType = event->contentJson()["org.matrix.msc3488.asset"_ls].toObject()["type"_ls].toString();
+    const auto assetType = event->contentJson()["org.matrix.msc3488.asset"_L1].toObject()["type"_L1].toString();
     if (assetType.isEmpty()) {
         return {};
     }
