@@ -48,6 +48,11 @@ QQuickItem *QmlUtils::focusedWindowItem()
     }
 }
 
+QString QmlUtils::nameForPowerLevelValue(const int value)
+{
+    return PowerLevel::nameForLevel(PowerLevel::levelForValue(value));
+}
+
 bool Utils::isEmoji(const QString &text)
 {
 #ifdef HAVE_ICU
